@@ -7,14 +7,14 @@ from pathlib import Path
 
 class PdfPrinter(BatchPrinter):
 
-    def render(self, batch_dictionaries):
+    def render(self, batch_dictionaries, print_definition):
         with TemporaryStorage() as storage:
             path = Path(storage.folder) / 'printer-configuration.json'
             with open(path, 'wt') as f:
                 json.dump({
                     'uri': self.server_uri,
-                    'folder': self.target_folder,
                     'batch_dictionaries': batch_dictionaries,
+                    'print_definition': print_definition,
                 }, f)
             subprocess.run([
                 'node',
